<?php

$LANG = array(

'L_MENU'													=> 'Menu',
'L_UNKNOWN_ERROR'											=> 'Erro desconhecido',
'L_CONFIRM_DELETE'											=> 'Confirme a eliminação ?',
'L_SAVE_FILE'												=> 'Salve o arquivo',
'L_SAVE_FILE_SUCCESSFULLY'									=> 'Arquivo salvo com sucesso',
'L_SAVE_FILE_ERROR'											=> 'Salvar o arquivo para o erro',
'L_REPLY'													=> 'Resposta',
'L_REPLY_TO'												=> 'Resposta',
'L_CANCEL'													=> 'Cancelar',
'L_DELETE'													=> 'Excluir',
'L_DELETE_FILE' 				    						=> 'Excluir arquivo',
'L_DELETE_FOLDER'				   							=> 'Excluir pasta',
'L_THUMBNAIL'												=> 'Miniatura (facultativo)',
'L_THUMBNAIL_SELECTION'										=> 'Selecionar Imagem',
'L_THUMBNAIL_TITLE'											=> 'Título de Imagem (facultativo)',
'L_THUMBNAIL_ALT'											=> 'Texto alternativo da imagem (facultativo)',
'L_SAVE_SUCCESSFUL'											=> 'Grabação dos dados efectuada com sucesso',
'L_SAVE_ERR'												=> 'Ocorreu um erro durante o processo de grabação dos dados',
'L_NO_ENTRY'												=> 'Acesso refusado',
'L_ERR_USER_EMPTY'											=> 'Queira dígitar um nome de utilizador',
'L_ERR_PASSWORD_EMPTY'										=> 'Queira dígitar uma senha',
'L_ERR_PASSWORD_EMPTY_CONFIRMATION'							=> 'A confirmação da senha está errada',
'L_ERR_INVALID_EMAIL'										=> 'Enderêço e-mail inválido',
'L_ERR_INVALID_SITE'										=> 'Enderêço do web-site inválido',
'L_ERR_INVALID_ARTICLE_IDENT'								=> 'Identificante do artigo inválido !',
'L_DEFAULT_NEW_CATEGORY_URL'								=> 'nova-categoria',
'L_DEFAULT_NEW_STATIC_URL'									=> 'nova-página',
'L_DEFAULT_NEW_ARTICLE_URL'									=> 'novo-artigo',
'L_ARTICLE_SAVE_SUCCESSFUL'									=> 'Artigo criado com sucesso',
'L_ARTICLE_MODIFY_SUCCESSFUL'								=> 'Artigo actualizado com sucesso',
'L_ARTICLE_DELETE_SUCCESSFUL'								=> 'Suppressão efectuada com sucesso',
'L_ARTICLE_SAVE_ERR'										=> 'Erro a salvaguarda do artigo',
'L_ARTICLE_DELETE_ERR'										=> 'Ocorreu um erro durante o processo de supressão do artigo',
'L_ERR_UNKNOWN_COMMENT'										=> 'O comentário ao qual faz refrência nunca existiu ou foi suprimido',
'L_COMMENT_SAVE_SUCCESSFUL'									=> 'Comentário alterado com sucesso',
'L_COMMENT_UPDATE_ERR'										=> 'Ocorreu um erro durante o processo de alteração do comentário',
'L_COMMENT_DELETE_SUCCESSFUL'								=> 'Supressão efectuada com sucesso',
'L_COMMENT_DELETE_ERR'										=> 'Ocorreu um erro durante o processo de supressão',
'L_COMMENT_VALIDATE_SUCCESSFUL'								=> 'Validatção efectuada com sucesso',
'L_COMMENT_VALIDATE_ERR'									=> 'Ocorreu um erro durante o processo de validação',
'L_COMMENT_MODERATE_SUCCESSFUL'								=> 'Moderação efectuada com sucesso',
'L_COMMENT_MODERATE_ERR'									=> 'Ocorreu um erro durante o processo de moderação',
'L_COMMENT_WRITTEN_BY'										=> 'Escrito por',
'L_PLXMEDIAS_MEDIAS_FOLDER_ERR'								=> 'Impossivél de criar a pasta para os médias do utilizador conectado',
'L_PLXMEDIAS_ROOT'											=> 'raíz',
'L_PLXMEDIAS_NEW_FOLDER_ERR'								=> 'Impossivél de criar a pasta',
'L_PLXMEDIAS_NEW_FOLDER_SUCCESSFUL'							=> 'pasta criada com sucesso',
'L_PLXMEDIAS_NEW_FOLDER_EXISTS'								=> 'A pasta já existe',
'L_PLXMEDIAS_DEL_FOLDER_ERR'								=> 'Ocorreu um erro durante o processo de supressão da pasta',
'L_PLXMEDIAS_DEL_FOLDER_SUCCESSFUL'							=> 'pasta suprimida com sucesso',
'L_PLXMEDIAS_WRONG_FILEFORMAT'								=> 'O tipo de arquivo não é permitido',
'L_PLXMEDIAS_WRONG_FILESIZE'								=> 'O tamanho do ficheiro é superior ao;',
'L_PLXMEDIAS_UPLOAD_ERR'									=> 'Erro ao enviar um arquivo',
'L_PLXMEDIAS_UPLOAD_SUCCESSFUL'								=> 'Arquivo enviada com sucesso!',
'L_PLXMEDIAS_UPLOADS_ERR'									=> 'Erro ao carregar arquivos',
'L_PLXMEDIAS_UPLOADS_SUCCESSFUL'							=> 'Arquivos enviada com sucesso!',
'L_PLXMEDIAS_DELETE_FILES_SUCCESSFUL'						=> 'Removido com sucesso arquivos',
'L_PLXMEDIAS_DELETE_FILES_ERR'								=> 'Erro ao excluir um arquivo',
'L_PLXMEDIAS_DELETE_FILE_SUCCESSFUL'						=> 'Arquivo excluído com sucesso',
'L_PLXMEDIAS_DELETE_FILE_ERR'								=> 'Erro ao apagar o arquivo',
'L_PLXMEDIAS_MOVE_FILES_SUCCESSFUL'							=> 'Ficheiros movidos com sucesso',
'L_PLXMEDIAS_MOVE_FILE_SUCCESSFUL'							=> 'Ficheiro movido com sucesso',
'L_PLXMEDIAS_MOVE_FILES_ERR'								=> 'Ocorreu um erro durante o processo moção dos ficheiros',
'L_PLXMEDIAS_MOVE_FILE_ERR'									=> 'Ocorreu um erro durante o processo moção do ficheiro',
'L_PLXMEDIAS_MOVE_FOLDER'									=> 'Mover',
'L_PLXMEDIAS_RECREATE_THUMB_ERR'							=> 'Erro ao criar a miniatura',
'L_PLXMEDIAS_RECREATE_THUMBS_ERR'							=> 'Erro na criação de miniaturas',
'L_PLXMEDIAS_RECREATE_THUMB_SUCCESSFUL'						=> 'Miniatura criado com sucesso',
'L_PLXMEDIAS_RECREATE_THUMBS_SUCCESSFUL'					=> 'Miniaturas criado com sucesso',
'L_DEFAULT_NEW_ARTICLE_TITLE'								=> 'Novo artigo',
'L_ERR_INVALID_PUBLISHING_DATE'								=> 'Data de publicação inválida.',
'L_ERR_UNKNOWN_ARTICLE'										=> 'O artigo ao qual faz refrência nunca existiu ou foi suprimido!',
'L_ERR_FORBIDDEN_ARTICLE'									=> 'Voçê não tem os direitos necessários para visualizar este artigo!',
'L_BACK_TO_ARTICLES'										=> 'Voltar à lista dos artigos',
'L_ARTICLE_EDITING'											=> 'Modificação de um artigo',
'L_ARTICLE_TITLE'											=> 'Titúlo',
'L_ARTICLE_LIST_AUTHORS'									=> 'Autor',
'L_HEADLINE_FIELD'											=> 'Chapéu; (facultativo)',
'L_CONTENT_FIELD'											=> 'Conteúdo',
'L_LINK_FIELD'												=> 'Link para o artigo',
'L_LINK_ACCESS'												=> 'Ir para o artigo',
'L_LINK_VIEW'												=> 'ver',
'L_ARTICLE_STATUS'											=> 'Estado',
'L_DRAFT'													=> 'Brouillon',
'L_PUBLISHED'												=> 'Publicado',
'L_AWAITING'												=> 'Validação pendente',
'L_ARTICLE_DATE'											=> 'Data de publicação',
'L_NOW'														=> 'agora',
'L_ARTICLE_CATEGORIES'										=> 'Local',
'L_CATEGORY_HOME_PAGE'										=> 'Página de inicio',
'L_NEW_CATEGORY'											=> 'Nova categoria',
'L_ARTICLE_TAGS_FIELD'										=> 'Tags',
'L_ARTICLE_TAGS_FIELD_TITLE'								=> 'Separe os tags com uma virgúla',
'L_ARTICLE_TOGGLER_TITLE'									=> 'Lista de tags',
'L_NO_TAG'													=> 'Nenhum tag',
'L_ALLOW_COMMENTS'											=> 'Autorizar os comentários',
'L_ARTICLE_URL_FIELD'										=> 'Url',
'L_ARTICLE_URL_FIELD_TITLE'									=> 'O URL se preenche automáticamente com o titúlo do seu artigo',
'L_ARTICLE_TEMPLATE_FIELD'									=> 'Template',
'L_ARTICLE_MANAGE_COMMENTS'									=> 'Gerir os comentários',
'L_ARTICLE_MANAGE_COMMENTS_TITLE'							=> 'Gerir os comentários deste artigo',
'L_ARTICLE_NEW_COMMENT'										=> 'Digitar um comentário',
'L_ARTICLE_NEW_COMMENT_TITLE'								=> 'Digitar um comentário sobre este artigo',
'L_ARTICLE_DELETE_CONFIRM'									=> 'Suprimir este artigo ?',
'L_ARTICLE_PREVIEW_BUTTON'									=> 'Pré-vizualização',
'L_ARTICLE_DRAFT_BUTTON'									=> 'Grabar brouillon',
'L_ARTICLE_PUBLISHING_BUTTON'								=> 'Publicar',
'L_ARTICLE_MODERATE_BUTTON'									=> 'Submeter à aprovação',
'L_ARTICLE_OFFLINE_BUTTON'									=> 'Por offline',
'L_ARTICLE_UPDATE_BUTTON'									=> 'Grabar',
'L_CATEGORY_ADD_BUTTON'										=> 'Adicionar',
'L_ARTICLE_META_DESCRIPTION'								=> 'Conteúdo da baliza meta "description" (opção)',
'L_ARTICLE_META_KEYWORDS'									=> 'Conteúdo da baliza meta "keywords" (opção)',
'L_ARTICLE_TITLE_HTMLTAG'									=> 'Conteúdo da tag título (opcional)',
'L_ARTICLE_CHAPO_HIDE'										=> 'esconder',
'L_ARTICLE_CHAPO_DISPLAY'									=> 'mostrar',
'L_ARTICLE'													=> 'artigo',
'L_ARTICLE_ID'												=> 'Nome interno',
'L_AUTH_PAGE_TITLE'											=> 'Página de identificação',
'L_LOGOUT_SUCCESSFUL'										=> 'Foi correctamente deconectado',
'L_LOGIN_PAGE'												=> 'Conexão á zona de administração ',
'L_AUTH_LOGIN_FIELD'										=> 'Login de conexão',
'L_AUTH_PASSWORD_FIELD'										=> 'Senha',
'L_SUBMIT_BUTTON'											=> 'Validar',
'L_ERR_WRONG_PASSWORD'										=> 'Login ou senha incorrecta',
'L_POWERED_BY'												=> 'Propulsado por: <a href="http://www.pluxml.org">PluXml</a>',
'L_CAT_TITLE'												=> 'Criação e edição das cetegorias',
'L_CAT_LIST_ID'												=> 'Nome interno',
'L_CAT_LIST_ACTIVE'											=> 'Activa',
'L_CAT_LIST_NAME'											=> 'Nome da categoria',
'L_CAT_LIST_URL'											=> 'Url',
'L_CAT_LIST_SORT'											=> 'Classificação',
'L_CAT_LIST_BYPAGE'											=> 'Artigos/página',
'L_CAT_LIST_ORDER'											=> 'Ordem',
'L_CAT_LIST_MENU'											=> 'Menu',
'L_CATEGORY'												=> 'Categoria',
'L_DISPLAY'													=> 'Mostrar',
'L_HIDE'													=> 'Esconder',
'L_OPTIONS'													=> 'Opções',
'L_FOR_SELECTION'											=> 'Para a selecção...',
'L_CAT_APPLY_BUTTON'										=> 'Alterar a lista das categorias',
'L_CAT_UNKNOWN'												=> 'categoria desconhecida',
'L_EDITCAT_PAGE_TITLE'										=> 'Edição das opções da categoria',
'L_EDITCAT_DESCRIPTION'										=> 'Descrição',
'L_EDITCAT_DISPLAY_HOMEPAGE'								=> 'Mostrar itens nesta categoria na página inicial',
'L_EDITCAT_TEMPLATE'										=> 'Template',
'L_EDITCAT_BACK_TO_PAGE'									=> 'Voltar á lista das categorias',
'L_EDITCAT_UPDATE'											=> 'Actualizar esta categoria',
'L_EDITCAT_TITLE_HTMLTAG'									=> 'Conteúdo da tag título (opcional)',
'L_EDITCAT_META_DESCRIPTION'								=> 'Conteúdo da baliza meta"description" para esta categoria (opção)',
'L_EDITCAT_META_KEYWORDS'									=> 'Conteúdo da baliza meta "keywords" para esta categoriae (opção)',
'L_COMMENT_ORPHAN'											=> 'nenhum artigo',
'L_COMMENT_ORPHAN_STATUS'									=> 'não visivél (aconselhamos a supressão deste comentário)',
'L_COMMENT_ARTICLE_LINKED'									=> 'Artigo',
'L_COMMENT_ARTICLE_LINKED_TITLE'							=> 'Artigo ligado a este comentário',
'L_COMMENT_OFFLINE'											=> 'offline',
'L_COMMENT_ONLINE'											=> 'online',
'L_COMMENT_ONLINE_TITLE'									=> 'Lista dos comentários publicados',
'L_BACK_TO_ARTICLE_COMMENTS'								=> 'Voltar à lista dos comentários deste artigo',
'L_BACK_TO_COMMENTS'										=> 'Voltar à lista dos comentários',
'L_COMMENT_EDITING'											=> 'Edição do comentário',
'L_COMMENT_AUTHOR_FIELD'									=> 'Autor',
'L_COMMENT_TYPE_FIELD'										=> 'Tipo comentário',
'L_COMMENT_DATE_FIELD'										=> 'Data e hora de publicação',
'L_COMMENT_IP_FIELD'										=> 'Ip',
'L_COMMENT_SITE_FIELD'										=> 'web-site',
'L_COMMENT_EMAIL_FIELD'										=> 'E-mail',
'L_COMMENT_STATUS_FIELD'									=> 'Statuto',
'L_COMMENT_LINKED_ARTICLE_FIELD'							=> 'Artigo ligado;',
'L_COMMENT_ARTICLE_FIELD'									=> 'Comentário',
'L_COMMENT_DELETE_CONFIRM'									=> 'Suprimir este comentário ?',
'L_COMMENT_PUBLISH_BUTTON'									=> 'Validar a publicação',
'L_COMMENT_OFFLINE_BUTTON'									=> 'Por offline',
'L_COMMENT_ANSWER_BUTTON'									=> 'Responder a este comentário',
'L_COMMENT_UPDATE_BUTTON'									=> 'Actualizar',
'L_ERR_ANSWER_UNKNOWN_COMMENT'								=> 'O comentário ao qual tenta responder nunca existiu ou foi suprimido !',
'L_ERR_ANSWER_OFFLINE_COMMENT'								=> 'O comentário está offline, impossivél de responder !',
'L_ERR_COMMENT_UNKNOWN_ARTICLE'								=> 'O artigo ao quel faz referência não foi suprimido, impossivél de escrever um comentário !',
'L_ERR_CREATING_COMMENT'									=> 'Ocorreu um erro durante o processo de criação do comentário',
'L_CREATING_COMMENT_SUCCESSFUL'								=> 'O comentário foi criado com sucesso',
'L_CREATE_NEW_COMMENT'										=> 'Dígitar um comentário',
'L_COMMENT_SAVE_BUTTON'										=> 'Grabar',
'L_ARTICLE_COMMENTS_LIST'									=> 'Comentários deste artigo (do mais recente ao mais antigo)',
'L_COMMENT_ANSWER_TITLE'									=> 'Responder a este comentário',
'L_COMMENT_ANSWER'											=> 'Responder',
'L_COMMENT_NEW_COMMENT_TITLE'								=> 'Dígitar um novo comentário para este artigo',
'L_COMMENT_NEW_COMMENT'										=> 'Dígitar um novo comentário',
'L_COMMENTS_ARTICLE_SCOPE'									=> 'Artigo',
'L_COMMENTS_GLOBAL_SCOPE'									=> 'web-site inteiro',
'L_COMMENTS_OFFLINE_LIST'									=> 'Lista dos comentários á espera de validação ',
'L_COMMENTS_LIST_DATE'										=> 'Data',
'L_COMMENTS_LIST_AUTHOR'									=> 'Autor',
'L_COMMENTS_LIST_MESSAGE'									=> 'Mensagem',
'L_COMMENTS_LIST_ACTION'									=> 'Ação',
'L_COMMENT_EDIT'											=> 'Editar',
'L_COMMENT_EDIT_TITLE'										=> 'Editar este comentário',
'L_COMMENT_DELETE'											=> 'Suprimir',
'L_COMMENT_OFFLINE_FEEDS_TITLE'								=> 'Fluxo rss dos comentários offline',
'L_COMMENT_OFFLINE_FEEDS'									=> 'Comentários offline',
'L_COMMENT_ONLINE_FEEDS_TITLE'								=> 'Fluxo rss dos comentários online',
'L_COMMENT_ONLINE_FEEDS'									=> 'Comentários online',
'L_COMMENTS_PRIVATE_FEEDS'									=> 'Fluxo de sindicação privado',
'L_COMMENTS_ONLINE_LIST'									=> 'Lista de opiniões publicadas',
'L_COMMENTS_ALL_LIST'										=> 'Lista de comentários',
'L_COMMENT_SET_ONLINE'										=> 'Take Online',
'L_COMMENT_SET_OFFLINE'										=> 'Take Offline',
'L_ARTICLES_FILTER_BUTTON'									=> 'Filtrar',
'L_CATEGORIES_TABLE'										=> 'Categorias',
'L_SPECIFIC_CATEGORIES_TABLE'								=> 'Locais específicos',
'L_ALL_ARTICLES_CATEGORIES_TABLE'							=> 'Todos os artigos',
'L_ARTICLES_LIST'											=> 'Lista dos artigos',
'L_ARTICLE_LIST_DATE'										=> 'Data',
'L_ARTICLE_LIST_TITLE'										=> 'Titúlo',
'L_ARTICLE_LIST_CATEGORIES'									=> 'Categoria',
'L_ARTICLE_LIST_NBCOMS'										=> 'Nro coms',
'L_ARTICLE_LIST_AUTHOR'										=> 'Autor',
'L_ARTICLE_LIST_ACTION'										=> 'Ação',
'L_CATEGORY_HOME'											=> 'Índice',
'L_CATEGORY_DRAFT'											=> 'Brouillon',
'L_ARTICLE_VIEW'											=> 'Visualizar',
'L_ARTICLE_VIEW_TITLE'										=> 'Visualizar este artigo no web-site',
'L_ARTICLE_EDIT'											=> 'Editar',
'L_ARTICLE_EDIT_TITLE'										=> 'Editar este artigo',
'L_NEW_COMMENTS_TITLE'										=> 'Comentários á espera de validação',
'L_VALIDATED_COMMENTS_TITLE'								=> 'Comentários publicados',
'L_NO_ARTICLE'												=> 'Nenhum artigo',
'L_ARTICLES_SEARCH_BUTTON'									=> 'Pesquisa',
'L_ARTICLES_ALL_CATEGORIES'									=> 'Todas as categorias ...',
'L_ALL'														=> 'Todos',
'L_ALL_PUBLISHED'											=> 'Publicação',
'L_ALL_DRAFTS'												=> 'Rascunhos',
'L_ALL_AWAITING_MODERATION'									=> 'Validação pendente',
'L_MEDIAS_DELETE_FOLDER'									=> 'Suprimir a  pasta',
'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Suprimir a pasta %s e o seu conteúdo ?',
'L_MEDIAS_NO_FILE'											=> 'Nenhum ficheiro',
'L_MEDIAS_FILENAME'											=> 'Nome de ficheiro',
'L_MEDIAS_ADD_FILE'											=> 'Adicionar o ficheiro',
'L_MEDIAS_BACK'												=> 'Voltar',
'L_MEDIAS_TITLE'											=> 'Gestão dos médias',
'L_MEDIAS_IMAGES'											=> 'Imagens',
'L_MEDIAS_DOCUMENTS'										=> 'Documentos',
'L_MEDIAS_CREATE_FOLDER'									=> 'Criar uma pasta',
'L_MEDIAS_SUBMIT_FILE'										=> 'Enviar',
'L_MEDIAS_MAX_UPOLAD_FILE'									=> 'Tamanho máximo dos ficheiros',
'L_MEDIAS_DIRECTORY'										=> 'Localização',
'L_MEDIAS_FOLDER'											=> 'Arquivo',
'L_MEDIAS_NEW_FOLDER'										=> 'Nova Pasta',
'L_MEDIAS_FILESIZE'											=> 'Tamanho',
'L_MEDIAS_DATE'												=> 'Data',
'L_MEDIAS_DIMENSIONS'										=> 'Dimensões',
'L_MEDIAS_RESIZE'											=> 'Redimensionar Imagens',
'L_MEDIAS_RESIZE_NO'										=> 'Tamanho Original',
'L_MEDIAS_THUMBS'											=> 'Criar miniaturas',
'L_MEDIAS_THUMBS_NONE'										=> 'Não miniatura',
'L_MEDIAS_MODIFY'											=> 'Editar',
'L_MEDIAS_THUMB'											=> 'Miniatura',
'L_MEDIAS_EXTENSION'										=> 'Extensão',
'L_MEDIAS_ADD'												=> 'Adicionar',
'L_MEDIAS_ALIGNMENT'										=> 'Alinhamento',
'L_MEDIAS_ALIGN_NONE'										=> 'Não',
'L_MEDIAS_ALIGN_LEFT'										=> 'Esquerda',
'L_MEDIAS_ALIGN_CENTER'										=> 'Centro',
'L_MEDIAS_ALIGN_RIGHT'										=> 'Direito',
'L_MEDIAS_RECREATE_THUMB'									=> 'Recriar de miniaturas',
'L_SORT_ASCENDING_DATE'										=> 'data ascendente',
'L_SORT_DESCENDING_DATE'									=> 'data decrescente',
'L_SORT_ALPHABETICAL'										=> 'alfabético',
'L_OK'														=> 'Ok',
'L_YES'														=> 'Sim',
'L_NO'														=> 'Não',
'L_NONE1'													=> 'nenhum',
'L_NONE2'													=> 'nenhuma',
'L_CONFIG_VIEW_FIELD'										=> 'Opções de exibição',
'L_CONFIG_VIEW_SKIN_SELECT'									=> 'Escolha do tema',
'L_CONFIG_VIEW_FILES_EDIT_TITLE'							=> 'Editar os ficheiros do tema',
'L_CONFIG_VIEW_FILES_EDIT'									=> 'Editar os ficheiros do tema',
'L_CONFIG_VIEW_SORT'										=> 'Classificação dos artigos ',
'L_CONFIG_VIEW_BYPAGE'										=> 'Numero de artigos mostrados / página',
'L_CONFIG_VIEW_BYPAGE_ARCHIVES'								=> 'Numero de artigos mostrados / página nos arquivos',
'L_CONFIG_VIEW_BYPAGE_ADMIN'								=> 'Numero de artigos mostrados / página na administração',
'L_CONFIG_VIEW_SORT_COMS'									=> 'Classificação dos comentários',
'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'							=> 'Numero de comentários mostrados / página na administração',
'L_CONFIG_VIEW_IMAGES'										=> 'Tamanho da imagem (largura x altura)',
'L_CONFIG_VIEW_THUMBS'										=> 'Tamanhos das miniaturas (largura x altura)',
'L_CONFIG_VIEW_HOMESTATIC'									=> 'Utilizar uma página stática como página de índice',
'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> 'Atenção esta página está inactiva',
'L_CONFIG_VIEW_PLUXML_RESSOURCES'							=> 'Descarregue outros temas em <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
'L_CONFIG_VIEW_BYPAGE_FEEDS'								=> 'Numero de artigos/comentários exibidoss nops fluxos Rss',
'L_CONFIG_VIEW_FEEDS_HEADLINE'								=> 'Mostrar sómente o chapéu dos artigos nos fluxos Rss',
'L_CONFIG_VIEW_FEEDS_HEADLINE_HELP'							=> 'Se o chapéu estiver vazio o conteúdo será exibido',
'L_CONFIG_VIEW_FEEDS_FOOTER'								=> 'Texto (assinatura) a inserir no fundo de cada fluxo Rss dos artigos',
'L_CONFIG_VIEW_UPDATE'										=> 'Alterar as opções de exibição',
'L_CONFIG_VIEW_DISPLAY_EMPTY_CAT'							=> 'Listar categorias sem artigo',
'L_CONFIG_HOMETEMPLATE'										=> 'Template da página inicial',
'L_CONFIG_ADVANCED_DESC'									=> 'Configuração avançada',
'L_CONFIG_ADVANCED_URL_REWRITE'								=> 'Activar a re-escritura dos URLS',
'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> 'Atenção um .htaccess já está presente na raiz do seu PluXml. Ao permitir a reescrita de URL este arquivo será modificado',
'L_CONFIG_ADVANCED_GZIP'									=> 'Activar a compressão GZIP',
'L_CONFIG_ADVANCED_GZIP_HELP'								=> 'Permite de comprimir as páginas afim de economizar os dados transferidos entre o servidor e o seu computer, em consequência aumenta a carga do servidor ! Desactive se o sue web-site fôr muito visitado',
'L_CONFIG_ADVANCED_CAPCHA'									=> 'Activar o capcha anti-spam',
'L_CONFIG_ADVANCED_ADMIN_KEY'								=> 'Chave de administração (URLS privadas)',
'L_CONFIG_ADVANCED_KEY_HELP'								=> 'Esvaziar o campo afim de regenerar a chave novamente',
'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Utilizar uma pasta medias diferente para cada utilizador',
'L_HELP_SLASH_END'											=> 'Não esquecêr o flash "/" no fim',
'L_CONFIG_ADVANCED_MEDIAS_FOLDER'							=> 'Mídia local (pasta)',
'L_CONFIG_ADVANCED_ARTS_FOLDER'								=> 'Local dos artigos (pasta)',
'L_CONFIG_ADVANCED_COMS_FOLDER'								=> 'Local dos comentários (pasta)',
'L_CONFIG_ADVANCED_STATS_FOLDER'							=> 'Local das páginas státicas (pasta)',
'L_CONFIG_ADVANCED_THEMES_FOLDER'							=> 'Localização de tópicos (pasta)',
'L_CONFIG_ADVANCED_PLUGINS_FOLDER'							=> 'Localização dos plugins (pasta)',
'L_CONFIG_ADVANCED_CONFIG_FOLDER'							=> 'Localização dos arquivos de configuração (pasta)',
'L_CONFIG_ADVANCED_UPDATE'									=> 'Alterar a configura avançada',
'L_CONFIG_CUSTOM_CSSADMIN_PATH'								=> 'Localização e nome do arquivo css personalizado da área de administração (opcional)',
'L_CONFIG_BASE_CONFIG_TITLE'								=> 'Configuração de base',
'L_CONFIG_BASE_SITE_TITLE'									=> 'Titúlo do web-site',
'L_CONFIG_BASE_SITE_SLOGAN'									=> 'Sob-titúlo/descrição do web-site',
'L_CONFIG_BASE_URL_HELP'									=> 'Não esquecer o flash "/" do fim',
'L_CONFIG_BASE_DEFAULT_LANG'								=> 'Idioma padrão do web-site',
'L_CONFIG_BASE_TIMEZONE'									=> 'Fuso horário',
'L_CONFIG_BASE_ALLOW_COMMENTS'								=> 'Autorizar os comentários',
'L_CONFIG_BASE_MODERATE_COMMENTS'							=> 'Moderar os comentários á criação',
'L_CONFIG_BASE_MODERATE_ARTICLES'							=> 'Moderar os artigos para os perfis Editor e Editor',
'L_CONFIG_BASE_UPDATE'										=> 'Alterar a configuração de base',
'L_CONFIG_META_DESCRIPTION'									=> 'Conteúdo da baliza meta "description" do web-site (opção)',
'L_CONFIG_META_KEYWORDS'									=> 'Conteúdo da baliza meta "keywords" do web-site (opção)',
'L_CONFIG_EDITTPL_ERROR_NOTHEME'							=> 'O tema não existe !',
'L_CONFIG_EDITTPL_TITLE'									=> 'Edição do tema',
'L_CONFIG_EDITTPL_SELECT_FILE'								=> 'Ecolha do ficheiro a editar :',
'L_CONFIG_EDITTPL_LOAD'										=> 'Carregar',
'L_CONFIG_INFOS_TITLE'										=> 'Informações relativas ao PluXml',
'L_CONFIG_INFOS_DESCRIPTION'								=> 'Esta informações o informão sobre o funcionamento de PluXml e poder ser uteis em caso de disfuncionamento do sistema.',
'L_CONFIG_INFOS_NB_CATS'									=> 'Numero de categorias :',
'L_CONFIG_INFOS_NB_STATICS'									=> 'Numero de páginas státicas:',
'L_CONFIG_INFOS_WRITER'										=> 'Nome do redactor na sessão :',
'L_PLUXML_CHECK_VERSION'									=> 'Verificação do numero de versão no web-site oficial PluXml.org',
'L_PLUXML_UPDATE_UNAVAILABLE'								=> 'Impossivél verificar a exestência de novas actualizações, enquanto a função \'allow_url_fopen\' estiver desactivada neste sistema',
'L_PLUXML_UPDATE_ERR'										=> 'A verificação de novas actualizações abortou por razões desconhecidas',
'L_PLUXML_UPTODATE'											=> 'Está a utilizar a ultima versão de PluXml',
'L_PLUXML_UPDATE_AVAILABLE'									=> 'Uma nova versão de PluXml está disponivél ! pode descarregá-la em',
'L_CONFIG_USERS_TITLE'										=> 'Gestão dos utilizadores',
'L_CONFIG_USER'												=> 'Utilizador',
'L_CONFIG_USERS_ID'											=> 'Numero do utilizador',
'L_CONFIG_USERS_ACTIVE'										=> 'Activo',
'L_CONFIG_USERS_ACTION'										=> 'Ação',
'L_CONFIG_USERS_NEW'										=> 'Novo utilizador',
'L_CONFIG_USERS_UPDATE'										=> 'Alterar a lista dos utilizadores',
'L_ERR_LOGIN_ALREADY_EXISTS'								=> 'ID de login já utilizados',
'L_ERR_USERNAME_ALREADY_EXISTS'								=> 'Nome de Usuário já está em uso',
'L_ERR_CATEGORY_ALREADY_EXISTS'								=> 'Categoria nome já utilizado',
'L_ERR_STATIC_ALREADY_EXISTS'								=> 'Como já foi utilizado',
'L_BACK_TO_PLUGINS'											=> 'Voltar á página dos plugins',
'L_NO_PLUGIN'												=> 'Nenhum plugin',
'L_PLUGIN_NO_CONFIG'										=> 'Plugin não configurado',
'L_PLUGINS_CSS'												=> 'Css',
'L_PLUGINS_CSS_TITLE'										=> 'Edite o código css do plugin',
'L_CONTENT_FIELD_FRONTEND'									=> 'Site de conteúdo do arquivo Css',
'L_CONTENT_FIELD_BACKEND'									=> 'Css administrador de conteúdo de arquivo',
'L_PLUGINS_TITLE'											=> 'Gestão dos plugins',
'L_PLUGINS_VERSION'											=> 'Versão',
'L_PLUGINS_AUTHOR'											=> 'Autor',
'L_PLUGINS_ACTIVATE'										=> 'Activar',
'L_PLUGINS_DEACTIVATE'										=> 'Desactivar',
'L_PLUGINS_DELETE'											=> 'Suprimir',
'L_PLUGINS_DELETE_ERROR'									=> 'Ocoreu um erro durante a supressão',
'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Supressão efectuada com sucesso',
'L_PLUGINS_CONFIG'											=> 'Configuração',
'L_PLUGINS_CONFIG_TITLE'									=> 'Configuração do plugin',
'L_PLUGINS_REQUIREMENTS'									=> 'Nacessário',
'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Lista dos plugins presentes e activos para activar este plugin',
'L_PLUGINS_REQUIREMENTS_NONE'								=> 'Nenhum',
'L_PLUGINS_ALPHA_SORT'										=> 'Ordenar alfabeticamente plugins',
'L_PLUGINS_LOADING_SORT'									=> 'Carregando ordem',
'L_PLUGINS_ACTION'											=> 'Ação',
'L_PLUGINS_APPLY_BUTTON'									=> 'Alterar a lista de plugins',
'L_PLUGINS_ACTIVE_LIST'										=> 'Plugins ativos',
'L_PLUGINS_INACTIVE_LIST'									=> 'Plugins inativos',
'L_PROFIL_EDIT_TITLE'										=> 'Edição do seu perfil',
'L_PROFIL'													=> 'Perfil',
'L_PROFIL_LOGIN'											=> 'Login de conexão',
'L_PROFIL_USER'												=> 'Nome do utilizador',
'L_PROFIL_MAIL'												=> 'Enderêo e-mail',
'L_PROFIL_ADMIN_LANG'										=> 'Idioma do utilizador na administração',
'L_PROFIL_INFOS'											=> 'Informações',
'L_PROFIL_UPDATE'											=> 'Alterar o seu perfil',
'L_PROFIL_CHANGE_PASSWORD'									=> 'Alteração da senha',
'L_PROFIL_PASSWORD'											=> 'Senha',
'L_PROFIL_CONFIRM_PASSWORD'									=> 'Confirmação da senha',
'L_PROFIL_UPDATE_PASSWORD'									=> 'Alterar a sua senha',
'L_STATIC_BACK_TO_PAGE'										=> 'Voltar á lista das páginas státicas',
'L_STATIC_UNKNOWN_PAGE'										=> 'Esta página stática nunca existui ou foi suprimida !',
'L_STATIC_TITLE'											=> 'Edição página stática ',
'L_STATIC_VIEW_PAGE'										=> 'Visualizar a página',
'L_STATIC_ON_SITE'											=> 'directamente no web-site',
'L_STATIC_UPDATE'											=> 'Grabar esta página stática',
'L_STATIC_TITLE_HTMLTAG'									=> 'Conteúdo da tag título (opcional)',
'L_STATIC_META_DESCRIPTION'									=> 'Conteúdo da baliza meta "description" para esta página stática (opção)',
'L_STATIC_META_KEYWORDS'									=> 'Conteúdo da baliza meta "keywords" para esta página stática (opção)',
'L_STATICS_PAGE_TITLE'										=> 'Criação e edição das páginas státicas',
'L_STATICS_ID'												=> 'Identificante',
'L_STATICS_GROUP'											=> 'Groupo',
'L_STATICS_TITLE'											=> 'Titúlo',
'L_STATICS_URL'												=> 'Url',
'L_STATICS_ACTIVE'											=> 'Activa',
'L_STATICS_ORDER'											=> 'Ordem',
'L_STATICS_MENU'											=> 'Menu',
'L_STATICS_ACTION'											=> 'Ação',
'L_STATICS_TEMPLATE_FIELD'									=> 'Template',
'L_STATICS_PAGE_HOME'										=> 'Definir como página inicial',
'L_STATICS_HOME_PAGE'										=> 'Página<br />de inicio',
'L_PAGE'													=> 'Página',
'L_VIEW'													=> 'Vêr',
'L_STATICS_SRC_TITLE'										=> 'Editar o código fonte desta página',
'L_STATICS_SRC'												=> 'Editar',
'L_STATICS_NEW_PAGE'										=> 'Página nova',
'L_STATICS_UPDATE'											=> 'Alterar a lista das páginas státicas',
'L_PROFIL_ADMIN'											=> 'Administrador',
'L_PROFIL_MANAGER'											=> 'Gestionário',
'L_PROFIL_MODERATOR'										=> 'Moderador',
'L_PROFIL_EDITOR'											=> 'Editor',
'L_PROFIL_WRITER'											=> 'Redactor',
'L_ADMIN'													=> 'Administração',
'L_LOGIN'													=> 'Conectado como:',
'L_ADMIN_LOGOUT'											=> 'Deconectar',
'L_ADMIN_LOGOUT_TITLE'										=> 'Fechar a sessão de administração',
'L_BACK_TO_SITE'											=> 'Início',
'L_BACK_TO_SITE_TITLE'										=> 'Voltar ao início',
'L_BACK_TO_BLOG'											=> 'Blog',
'L_BACK_TO_BLOG_TITLE'										=> 'Voltar ao blog',
'L_MENU_ARTICLES'											=> 'Artigos',
'L_MENU_ARTICLES_TITLE'										=> 'Lista e modificação dos artigos',
'L_MENU_NEW_ARTICLES'										=> 'Novo artigo',
'L_MENU_NEW_ARTICLES_TITLE'									=> 'Novo artigo',
'L_MENU_STATICS_TITLE'										=> 'Lista e modificação das páginas státicas',
'L_MENU_STATICS'											=> 'Páginas státicas',
'L_MENU_COMMENTS_TITLE'										=> 'Lista e modificação dos comentários',
'L_MENU_COMMENTS'											=> 'Comentários',
'L_MENU_MEDIAS_TITLE'										=> 'Enviar e inserir um média',
'L_MENU_MEDIAS'												=> 'Médias',
'L_MENU_CATEGORIES_TITLE'									=> 'Criar, gerir ou editar as categorias',
'L_MENU_CATEGORIES'											=> 'Categorias',
'L_MENU_CONFIG_TITLE'										=> 'Configurar PluXml',
'L_MENU_CONFIG'												=> 'Parâmetros',
'L_MENU_PROFIL_TITLE'										=> 'Gerir o perfil do utilizador',
'L_MENU_PROFIL'												=> 'Perfil',
'L_WARNING_INSTALLATION_FILE'								=> 'O ficheiro install.php está presente na raíz de PluXml.<br />Por razões de segurança apague (delete) este ficheiro.',
'L_USER_UNKNOWN'											=> 'Utilizador desconhecido',
'L_USER_LANG'												=> 'Idioma utilizado na administração',
'L_USER_MAIL'												=> 'Enderêco e-mail',
'L_USER_INFOS'												=> 'Informações',
'L_USER_UPDATE'												=> 'Actualizar este utilizador',
'L_USER_PAGE_TITLE'											=> 'Edição das opções  do utilizador',
'L_USER_BACK_TO_PAGE'										=> 'Voltar á lista dos utilizadores',
'L_MENU_CONFIG_BASE_TITLE'									=> 'Alterar a configuração de base de PluXml',
'L_MENU_CONFIG_BASE'										=> 'Configuração de base',
'L_MENU_CONFIG_VIEW_TITLE'									=> 'Alterar as opções de exibição de Pluxml',
'L_MENU_CONFIG_VIEW'										=> 'Opções de exibição',
'L_MENU_CONFIG_USERS_TITLE'									=> 'Gerir as contas dos utilizadores',
'L_MENU_CONFIG_USERS'										=> 'Contas dos utilizadores',
'L_MENU_CONFIG_ADVANCED_TITLE'								=> 'Alterar a configuração avançada',
'L_MENU_CONFIG_ADVANCED'									=> 'Configuração avançada',
'L_MENU_CONFIG_INFOS_TITLE'									=> 'Ter informações sobre o seu PluXml',
'L_MENU_CONFIG_INFOS'										=> 'Informações',
'L_MENU_CONFIG_PLUGINS_TITLE'								=> 'Gerir os plugins',
'L_MENU_CONFIG_PLUGINS'										=> 'Plugins',
'L_ERR_URL_ALREADY_EXISTS'									=> 'Url já em uso. Por favor, altere o valor do campo \'Url\'',
'L_THEMES'													=> 'Temas',
'L_THEMES_TITLE'											=> 'Gerenciando temas',
'L_HELP'													=> 'Ajuda',
'L_HELP_TITLE'												=> 'Vêr a ajuda',
'L_BACK_TO_THEMES'											=> 'Voltar para os temas da página',
'L_ERR_INVALID_DATE_CREATION'								=> 'Data de criação inválido',
'L_ERR_INVALID_DATE_UPDATE'									=> 'Data inválida atualizado',
);
?>
